from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.base_request_builder import BaseRequestBuilder
from kiota_abstractions.base_request_configuration import RequestConfiguration
from kiota_abstractions.default_query_parameters import QueryParameters
from kiota_abstractions.get_path_parameters import get_path_parameters
from kiota_abstractions.method import Method
from kiota_abstractions.request_adapter import RequestAdapter
from kiota_abstractions.request_information import RequestInformation
from kiota_abstractions.request_option import RequestOption
from kiota_abstractions.serialization import Parsable, ParsableFactory
from typing import Any, Optional, TYPE_CHECKING, Union
from warnings import warn

if TYPE_CHECKING:
    from ...........models.e2_e_encrypted_payload import E2EEncryptedPayload
    from ...........models.operation_response import OperationResponse
    from ...........models.problem_details import ProblemDetails
    from ...........models.update_secret_request import UpdateSecretRequest
    from ...........models.update_secret_response import UpdateSecretResponse
    from .metadata.metadata_request_builder import MetadataRequestBuilder
    from .rollback.rollback_request_builder import RollbackRequestBuilder
    from .rotate.rotate_request_builder import RotateRequestBuilder
    from .rotation_policy.rotation_policy_request_builder import RotationPolicyRequestBuilder
    from .versions.versions_request_builder import VersionsRequestBuilder

class WithKeyItemRequestBuilder(BaseRequestBuilder):
    """
    Builds and executes requests for operations under /api/v1/projects/{-id}/environments/{envSlug}/providers/{providerSlug}/secrets/{key}
    """
    def __init__(self,request_adapter: RequestAdapter, path_parameters: Union[str, dict[str, Any]]) -> None:
        """
        Instantiates a new WithKeyItemRequestBuilder and sets the default values.
        param path_parameters: The raw url or the url-template parameters for the request.
        param request_adapter: The request adapter to use to execute the requests.
        Returns: None
        """
        super().__init__(request_adapter, "{+baseurl}/api/v1/projects/{%2Did}/environments/{envSlug}/providers/{providerSlug}/secrets/{key}", path_parameters)
    
    async def delete(self,request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> Optional[OperationResponse]:
        """
        DELETE_api_v1_projects_projectRef_environments_envSlug_providers_providerSlug_secrets_key
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[OperationResponse]
        """
        request_info = self.to_delete_request_information(
            request_configuration
        )
        from ...........models.problem_details import ProblemDetails

        error_mapping: dict[str, type[ParsableFactory]] = {
            "404": ProblemDetails,
        }
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from ...........models.operation_response import OperationResponse

        return await self.request_adapter.send_async(request_info, OperationResponse, error_mapping)
    
    async def get(self,request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> Optional[E2EEncryptedPayload]:
        """
        GET_api_v1_projects_projectRef_environments_envSlug_providers_providerSlug_secrets_key
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[E2EEncryptedPayload]
        """
        request_info = self.to_get_request_information(
            request_configuration
        )
        from ...........models.problem_details import ProblemDetails

        error_mapping: dict[str, type[ParsableFactory]] = {
            "400": ProblemDetails,
            "404": ProblemDetails,
        }
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from ...........models.e2_e_encrypted_payload import E2EEncryptedPayload

        return await self.request_adapter.send_async(request_info, E2EEncryptedPayload, error_mapping)
    
    async def put(self,body: UpdateSecretRequest, request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> Optional[UpdateSecretResponse]:
        """
        PUT_api_v1_projects_projectRef_environments_envSlug_providers_providerSlug_secrets_key
        param body: The request body
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: Optional[UpdateSecretResponse]
        """
        if body is None:
            raise TypeError("body cannot be null.")
        request_info = self.to_put_request_information(
            body, request_configuration
        )
        from ...........models.problem_details import ProblemDetails

        error_mapping: dict[str, type[ParsableFactory]] = {
            "400": ProblemDetails,
            "404": ProblemDetails,
        }
        if not self.request_adapter:
            raise Exception("Http core is null") 
        from ...........models.update_secret_response import UpdateSecretResponse

        return await self.request_adapter.send_async(request_info, UpdateSecretResponse, error_mapping)
    
    def to_delete_request_information(self,request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> RequestInformation:
        """
        DELETE_api_v1_projects_projectRef_environments_envSlug_providers_providerSlug_secrets_key
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        request_info = RequestInformation(Method.DELETE, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/json")
        return request_info
    
    def to_get_request_information(self,request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> RequestInformation:
        """
        GET_api_v1_projects_projectRef_environments_envSlug_providers_providerSlug_secrets_key
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        request_info = RequestInformation(Method.GET, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/json")
        return request_info
    
    def to_put_request_information(self,body: UpdateSecretRequest, request_configuration: Optional[RequestConfiguration[QueryParameters]] = None) -> RequestInformation:
        """
        PUT_api_v1_projects_projectRef_environments_envSlug_providers_providerSlug_secrets_key
        param body: The request body
        param request_configuration: Configuration for the request such as headers, query parameters, and middleware options.
        Returns: RequestInformation
        """
        if body is None:
            raise TypeError("body cannot be null.")
        request_info = RequestInformation(Method.PUT, self.url_template, self.path_parameters)
        request_info.configure(request_configuration)
        request_info.headers.try_add("Accept", "application/json")
        request_info.set_content_from_parsable(self.request_adapter, "application/json", body)
        return request_info
    
    def with_url(self,raw_url: str) -> WithKeyItemRequestBuilder:
        """
        Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
        param raw_url: The raw URL to use for the request builder.
        Returns: WithKeyItemRequestBuilder
        """
        if raw_url is None:
            raise TypeError("raw_url cannot be null.")
        return WithKeyItemRequestBuilder(self.request_adapter, raw_url)
    
    @property
    def metadata(self) -> MetadataRequestBuilder:
        """
        The metadata property
        """
        from .metadata.metadata_request_builder import MetadataRequestBuilder

        return MetadataRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def rollback(self) -> RollbackRequestBuilder:
        """
        The rollback property
        """
        from .rollback.rollback_request_builder import RollbackRequestBuilder

        return RollbackRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def rotate(self) -> RotateRequestBuilder:
        """
        The rotate property
        """
        from .rotate.rotate_request_builder import RotateRequestBuilder

        return RotateRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def rotation_policy(self) -> RotationPolicyRequestBuilder:
        """
        The rotationPolicy property
        """
        from .rotation_policy.rotation_policy_request_builder import RotationPolicyRequestBuilder

        return RotationPolicyRequestBuilder(self.request_adapter, self.path_parameters)
    
    @property
    def versions(self) -> VersionsRequestBuilder:
        """
        The versions property
        """
        from .versions.versions_request_builder import VersionsRequestBuilder

        return VersionsRequestBuilder(self.request_adapter, self.path_parameters)
    
    @dataclass
    class WithKeyItemRequestBuilderDeleteRequestConfiguration(RequestConfiguration[QueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
    
    @dataclass
    class WithKeyItemRequestBuilderGetRequestConfiguration(RequestConfiguration[QueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
    
    @dataclass
    class WithKeyItemRequestBuilderPutRequestConfiguration(RequestConfiguration[QueryParameters]):
        """
        Configuration for the request such as headers, query parameters, and middleware options.
        """
        warn("This class is deprecated. Please use the generic RequestConfiguration class generated by the generator.", DeprecationWarning)
    

