from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

@dataclass
class CopyEnvironmentCommand(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: dict[str, Any] = field(default_factory=dict)

    # The copyProviders property
    copy_providers: Optional[bool] = None
    # The copySecretKeys property
    copy_secret_keys: Optional[bool] = None
    # The description property
    description: Optional[str] = None
    # The name property
    name: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> CopyEnvironmentCommand:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: CopyEnvironmentCommand
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return CopyEnvironmentCommand()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        fields: dict[str, Callable[[Any], None]] = {
            "copyProviders": lambda n : setattr(self, 'copy_providers', n.get_bool_value()),
            "copySecretKeys": lambda n : setattr(self, 'copy_secret_keys', n.get_bool_value()),
            "description": lambda n : setattr(self, 'description', n.get_str_value()),
            "name": lambda n : setattr(self, 'name', n.get_str_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_bool_value("copyProviders", self.copy_providers)
        writer.write_bool_value("copySecretKeys", self.copy_secret_keys)
        writer.write_str_value("description", self.description)
        writer.write_str_value("name", self.name)
        writer.write_additional_data_value(self.additional_data)
    

